==> openshift-model-console-5.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleCLIDownloadBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadBuilder>{
  public ConsoleCLIDownloadBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleCLIDownload(), validationEnabled);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownload(), validationEnabled);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload build() {
    ConsoleCLIDownload buildable = new ConsoleCLIDownload(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCLIDownloadBuilder that = (ConsoleCLIDownloadBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.1-sources.jar: io/fabric8/openshift/api/model/console/v1/ConsoleCLIDownloadBuilder.java <==
package io.fabric8.openshift.api.model.console.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ConsoleCLIDownloadBuilder extends io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluentImpl<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadBuilder>{
  public ConsoleCLIDownloadBuilder() {
    this(false);
  }
  public ConsoleCLIDownloadBuilder(java.lang.Boolean validationEnabled) {
    this(new ConsoleCLIDownload(), validationEnabled);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ConsoleCLIDownload(), validationEnabled);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance) {
    this(fluent, instance, false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent,io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance) {
    this(instance,false);
  }
  public ConsoleCLIDownloadBuilder(io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownloadFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.console.v1.ConsoleCLIDownload build() {
    ConsoleCLIDownload buildable = new ConsoleCLIDownload(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsoleCLIDownloadBuilder that = (ConsoleCLIDownloadBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
